@@ -419,6 +419,7 @@ class IPN(models.Model):
     Internal Part Number.
 
     :code: The actual part number.
+    :code2: TODO: Describe this
     :name: A name for this IPN.
     :price_group: The price group, this IPN is in.
     :shape: TODO
@@ -436,6 +437,12 @@ class IPN(models.Model):
         max_length=50,
     )
 
+    code2 = models.CharField(
+        verbose_name=_('Code 2'),
+        max_length=50,
+        blank=True, null=True,
+    )
+
     name = models.CharField(
         verbose_name=_('Name'),
         max_length=128,
